@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11069 2018-05-21 10:18:52Z Lavender $
+# $Id: views.py 12270 2020-05-26 04:48:53Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2018-05-21 18:18:52 +0800 (週一, 21 五月 2018) $
-# $Revision: 11069 $
+# $Author: Trista $
+# $Date: 2020-05-26 12:48:53 +0800 (週二, 26 五月 2020) $
+# $Revision: 12270 $
 
 import datetime
 import hashlib
@@ -27,6 +27,7 @@ import urllib
 
 from bs4 import BeautifulSoup
 from unidecode import unidecode
+from urllib import parse 
 
 from django.contrib import auth
 from django.contrib.sites.models import Site
@@ -342,9 +343,9 @@ def showTargetFile(request):
                 
             mimeType = mimetypes.guess_type(targetFile.original_filename)
             if mimeType is not None:
-                contentType = mimeType[0]
+                contentType = mimeType[0] + ';charset=utf-8'
             else:
-                contentType = 'application/force-download'
+                contentType = 'application/force-download;charset=utf-8'
             if callToActionStatistics.action.fileName:
                 fileName = callToActionStatistics.action.fileName + '.' +targetFile.original_filename.split('.')[-1]
             else:
@@ -353,8 +354,9 @@ def showTargetFile(request):
                 file,
                 content_type=contentType
             )
+            safeFileName = parse.quote(fileName)
             response['Content-Disposition'] = (
-                        "attachment; filename=%s" % (fileName, ))
+                        f"attachment; filename={safeFileName}; filename*={safeFileName}")
             response['Content-Transfer-Encoding'] = 'binary'
             return response
 
@@ -416,12 +418,13 @@ def showTargetFile(request):
                 file = f.read()
             response = HttpResponse(
                 file,
-                content_type='application/pdf'
+                content_type='application/pdf;charset=utf-8'
             )
+            
+            safeFileName = parse.quote(fileName)
             response['Content-Disposition'] = (
-                        "attachment; filename=%s" % (fileName, ))
+                        f"attachment; filename={safeFileName}; filename*={safeFileName}")
             response['Content-Transfer-Encoding'] = 'binary'
-            # with chinese character in filename the file cannot dowload directly
 
             return response
 
