@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11641 2019-06-19 07:33:01Z Lavender $
+# $Id: models.py 11861 2020-01-14 12:00:19Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-06-19 16:33:01 +0900 (週三, 19 六月 2019) $
-# $Revision: 11641 $
+# $Date: 2020-01-14 20:00:19 +0800 (週二, 14 一月 2020) $
+# $Revision: 11861 $
 
 import datetime
 
@@ -65,7 +65,7 @@ class Comment(models.Model):
         editable=False, null=True, db_index=True)
     
     user = models.ForeignKey(
-        settings.AUTH_USER_MODEL, null=True, blank=True, verbose_name=_("User"),)
+        settings.AUTH_USER_MODEL, null=True, blank=True, verbose_name=_("User"), on_delete=models.CASCADE,)
     email = models.EmailField(
         verbose_name=_("Email"), max_length=254, null=True, blank=True)
     
